@@ -14,4 +14,9 @@ class BaseConfig(BaseSettings):
     AWS_SECRET_KEY: str = ""
     AWS_REGION: str = ""
     AWS_PARAMETER_PATH_PREFIX: str = ""
-    AWS_LOGGROUP_NAME: str = ""
\ No newline at end of file
+    AWS_LOGGROUP_NAME: str = ""
+
+    # Celery config
+    CELERY_APP: str|None = ""
+    CELERY_BROKER_URL: str|None = ""
+    CELERY_BACKEND_URL: str|None = ""
\ No newline at end of file
